@@ -3,20 +3,21 @@
 use strict;
 use Games::Cards::ShuffleTrack;
 
-###                                                         ###
+###															###
 ### This is a simple demonstration of a friendly poker game ###
-###                                                         ###
+###															###
 
 my $deck = Games::Cards::ShuffleTrack->new();
 my @hands;
-push @hands, Games::Cards::ShuffleTrack->new('empty') for 1 .. 5;
-
+for ( 1 .. 5 ) {
+    push @hands, Games::Cards::ShuffleTrack->new('empty');
+}
 $deck->riffle_shuffle() for 1 .. 12;
 $deck->cut();
 
 for ( 1 .. 5 ) {
     for my $hand ( @hands ) {
-        $deck->deal( $hand );
+        $hand->put( $deck->deal() );
     }
 }
 
